module Skrill
  class Payment::Configuration
    OPTIONS = [:merchant_email, :merchant_password, :currency, :subject, :note, :http_proxy]

    class << self
      include Skrill::Payment::Utils

      attr_accessor *OPTIONS

      # Sets the Skrill::Payment::Configuration options. Attributes can be
      # passed in by using a block or a Hash. The Skrill API expects the
      # merchant password to be a MD5 hash generated from the password
      # entered in the Skrill developer settings page.
      #
      # @example Set a configuration option.
      #   Skrill::Payment::Configuration.configure do |config|
      #     config.merchant_email = 'merchant@example.com'
      #     config.merchant_password = '7813258ef8c6b632dde8cc80f6bda62f'
      #   end
      #
      # @return [ Configuration ] The configuration object.
      #
      # @since 0.1.0
      def configure(options = {}, &block)
        Skrill::Payment::Configuration.tap do |config|
          options.each { |option, value| config.public_send("#{option}=", value) }

          yield(config) if block_given?
        end
      end

      # Returns all Skrill::Payment::Configuration options in a Hash.
      #
      # @return [ Hash ] The configuration options.
      #
      # @since 0.1.0
      def serialized_data
        serialize_arguments(OPTIONS)
      end
    end
  end
end
